#===============================================================================
# CERN (BE-CO-HT)
# I2C exceptions
#===============================================================================
# author: Theodor Stana (t.stana@cern.ch)
#
# date of creation: 2013-08-14
#
# version: 1.0
#
# description:
#     This module defines exceptions for the I2C class. These exeptions basically
#     correspond to errors that the ELMA SysMon can return.
#
#===============================================================================
# GNU LESSER GENERAL PUBLIC LICENSE
#===============================================================================
# This source file is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by the
# Free Software Foundation; either version 2.1 of the License, or (at your
# option) any later version. This source is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU Lesser General Public License for more details. You should have
# received a copy of the GNU Lesser General Public License along with this
# source; if not, download it from http://www.gnu.org/licenses/lgpl-2.1.html
#===============================================================================
# last changes:
#    2013-08-14    Theodor Stana    File created
#    2014-01-10    Theodor Stana    Changed name vbcp -> i2c
#===============================================================================
#  TODO: -
#===============================================================================

#===============================================================================
# Main exception class
#===============================================================================
class EI2CException(Exception):

  """Throw I2C exceptions.

  Subclasses:
  * BadHostnameError
  * BadUsernameError
  * BadPasswordError
  * NAckError
  * RegNumbererror
  * SlotError
  * TimerExpiredError
  """

  pass

#===============================================================================
# Bad hostname or address exception
#===============================================================================
class BadHostnameError(EI2CException):
  """Throw a bad hostname exception when the username is wrong"""

  strerror = "Bad IP address or hostname!"

  def __str__(self):
    return self.strerror

#===============================================================================
# Bad username exception
#===============================================================================
class BadUsernameError(EI2CException):
  """Throw a bad username exception when the username is wrong"""

  strerror = "Bad username!"

  def __str__(self):
    return self.strerror

#===============================================================================
# Bad pasword exception
#===============================================================================
class BadPasswordError(EI2CException):
  """Throw a bad password exception when the username is wrong"""

  strerror = "Bad password!"

  def __str__(self):
    return self.strerror

#===============================================================================
# Not Acknowledged exception
#===============================================================================
class NAckError(EI2CException):

  """Throw NACK exception when the module does not acknowledge."""

  strerror = "I2C NACK received."

  def __str__(self):
    return self.strerror

#===============================================================================
# Register number exception
#===============================================================================
class RegNumberError(EI2CException):

  """Throw register number exception."""

  strerror = "Invalid register number."

  def __str__(self):
    return self.strerror

#===============================================================================
# Invalid command exception
#===============================================================================
class InvalidCmdError(EI2CException):

  """Throw invalid command exception."""

  strerror = "Bad command exception."

  def __str__(self):
    return self.strerror

#===============================================================================
# I2C Timer Expired exception
#===============================================================================
class TimerExpiredError(EI2CException):

  """Throw I2C timer expired exception."""

  strerror = "I2C Timer Expired exception."

  def __str__(self):
    return self.strerror

#===============================================================================
# Invalid slot number exception
#===============================================================================
class SlotError(EI2CException):

  strerror = "Invalid slot number error."

  def __str__(self):
    return self.strerror
